==> alibabacloud_mse20190531_py2-3.0.61.tar.gz: alibabacloud_mse20190531_py2-3.0.61/ChangeLog.md <==
2023-03-02 Version: 3.0.60
- Fixed errorCode for Gateway API.
- Fixed errorCode for Gateway apis.
- Support no login.
- Fix bug for action segment.
- Supported for route type.
- Supported for gateway config version controller.
- Fixed configLevel.
- Delete isdelete segment.
- Fixed UpgradeGateway resource group.
- Support Eureka item on-off buttom.

2023-02-15 Version: 3.0.59
- Fixed ErrorCode for UpdateGatewayRoute.
- Fixed ErrorCode for AddGatewayRoute.

2023-02-02 Version: 3.0.58
- Suport mse nologin.
- Support mse nologin.
- Fixed bugs timeout for ListEngineNamespaces.
- Fixed api description.
- Support change mseVersion.
- Support listNamespace source type.
- Support for checking Lua.

2023-01-12 Version: 3.0.57
- Insert ahas into mse.
- Supported gray.

2023-01-11 Version: 3.0.56
- Fixed bugs for UpdateGatewaySls.
- Traffic gover block.

2023-01-09 Version: 3.0.55
- Supported gateway new parameters.
- Insert AHAS into mse.

2023-01-03 Version: 3.0.54
- Support zookeeper extendedTypesEnabled.

2022-12-30 Version: 3.0.53
- Fix read.
- Fix writeOrRead type.
- Supported for gateway auth with header paramters.

2022-12-23 Version: 3.0.52
- Modify api read type.

2022-12-16 Version: 3.0.51
- Supported active notification and process details for losslessRule.

2022-12-16 Version: 3.0.50
- Supported For Plugin Market v2.
- Support For Plugin Log.
- Suport taishan.
- Support zk export data.
- Support app_ip.
- Support un login.
- Support no login.
- Suport no login.
- Supported For Sls Config.
- Fix CreateNacosInstance userRateLimit.
- Fix Cluster relation.

2022-12-06 Version: 3.0.49
- Adjust timeout.
- Support running env.

2022-11-28 Version: 3.0.48
- Change timeout of GetApplicationList.
- Update timeout for DeleteGateway.
- Update timeout for AddGateway.
- Update GetKubernetesSource.
- Change some segment read only.
- Supported For Zk Track.

2022-11-22 Version: 3.0.47
- Support riskNotice switch.
- Change some segment to read only.
- Supported For Gateway RegExp Test.
- No change.
- Fixed Docs For These API.
- Adjust timeout.
- Change some segment from optional to necessary.

2022-11-15 Version: 3.0.46
- MSE.
- Fixed Describe For These API.

2022-11-15 Version: 3.0.45
- Support MSE and AHAS integrated.

2022-11-07 Version: 3.0.44
- Supported MSE Gateway For ResourceGroup.

2022-11-07 Version: 3.0.43
- Supported MSE Gateway For ResourceGroup.

2022-11-04 Version: 3.0.42
- Change some optional segment to necessary.

2022-10-25 Version: 3.0.41
- Automatically generate sdk tasks.

2022-10-14 Version: 3.0.40
- Automatically generate sdk tasks.

2022-10-13 Version: 3.0.39
- Automatically generate sdk tasks.

2022-10-12 Version: 3.0.38
- Add normandy api.

2022-09-28 Version: 3.0.30
- Automatically generate sdk tasks.

2022-09-27 Version: 3.0.29
- Automatically generate sdk tasks.

2022-09-27 Version: 3.0.28
- Automatically generate sdk tasks.

2022-09-22 Version: 3.0.27
- Automatically generate sdk tasks.

2022-09-21 Version: 3.0.26
- Automatically generate sdk tasks.

2022-09-15 Version: 3.0.25
- Automatically generate sdk tasks.

2022-09-15 Version: 3.0.24
- Automatically generate sdk tasks.

2022-06-21 Version: 3.0.23
- Add Seata List Cluster open.
- Add Seata List Group.

2022-06-20 Version: 3.0.22
- Add UpdateGatewaySpec open.
- Add UpdateClusterSpec open.

2022-02-18 Version: 3.0.9
- Add Gateway route api.

2021-10-12 Version: 1.0.1
- Add AddRoutePolicyRequest.

2021-04-15 Version: 1.0.0
- Publish first version.

==> alibabacloud_mse20190531_py2-3.0.65.tar.gz: alibabacloud_mse20190531_py2-3.0.65/ChangeLog.md <==
2023-03-30 Version: 3.0.64
- Improve SwimmingLane API.
- Improve error code.
- Change action segment.
- Improve QueryAllSwimmingLaneGroup API.
- Supported for jwt.
- Publish API QueryNamespace.
- Update QueryNamespace.
- Update API QueryNamespace.
- Update API DeleteNamespace.
- Fixed ErrorCode for UpdateAcl.
- Update Tag Policy API.
- Fixed bid for CreateCluster.
- Support ram check in different namespace.
- Support ram check in different namespaces.

2023-03-07 Version: 3.0.63
- Fixed ErrorCode for UpgradeCluster.
- Update FC for ImportServices.

2023-03-07 Version: 3.0.62
- Supported for route debug.
- API optimization for SwimmingLane.
- Support circuit breaker rule.
- Improve swimming lane.
- Change GetServiceMethodPageWithMetrics and GetDubboServicePageWithMetrics parameters.
- Change parameters of GetServiceMethodPageWithMetrics and GetDubboServicePageWithMetrics.

2023-03-02 Version: 3.0.61
- Update QueryConfig.
- Supporte for Edas gray.

2023-03-02 Version: 3.0.60
- Fixed errorCode for Gateway API.
- Fixed errorCode for Gateway apis.
- Support no login.
- Fix bug for action segment.
- Supported for route type.
- Supported for gateway config version controller.
- Fixed configLevel.
- Delete isdelete segment.
- Fixed UpgradeGateway resource group.
- Support Eureka item on-off buttom.

2023-02-15 Version: 3.0.59
- Fixed ErrorCode for UpdateGatewayRoute.
- Fixed ErrorCode for AddGatewayRoute.

2023-02-02 Version: 3.0.58
- Suport mse nologin.
- Support mse nologin.
- Fixed bugs timeout for ListEngineNamespaces.
- Fixed api description.
- Support change mseVersion.
- Support listNamespace source type.
- Support for checking Lua.

2023-01-12 Version: 3.0.57
- Insert ahas into mse.
- Supported gray.

2023-01-11 Version: 3.0.56
- Fixed bugs for UpdateGatewaySls.
- Traffic gover block.

2023-01-09 Version: 3.0.55
- Supported gateway new parameters.
- Insert AHAS into mse.

2023-01-03 Version: 3.0.54
- Support zookeeper extendedTypesEnabled.

2022-12-30 Version: 3.0.53
- Fix read.
- Fix writeOrRead type.
- Supported for gateway auth with header paramters.

2022-12-23 Version: 3.0.52
- Modify api read type.

2022-12-16 Version: 3.0.51
- Supported active notification and process details for losslessRule.

2022-12-16 Version: 3.0.50
- Supported For Plugin Market v2.
- Support For Plugin Log.
- Suport taishan.
- Support zk export data.
- Support app_ip.
- Support un login.
- Support no login.
- Suport no login.
- Supported For Sls Config.
- Fix CreateNacosInstance userRateLimit.
- Fix Cluster relation.

2022-12-06 Version: 3.0.49
- Adjust timeout.
- Support running env.

2022-11-28 Version: 3.0.48
- Change timeout of GetApplicationList.
- Update timeout for DeleteGateway.
- Update timeout for AddGateway.
- Update GetKubernetesSource.
- Change some segment read only.
- Supported For Zk Track.

2022-11-22 Version: 3.0.47
- Support riskNotice switch.
- Change some segment to read only.
- Supported For Gateway RegExp Test.
- No change.
- Fixed Docs For These API.
- Adjust timeout.
- Change some segment from optional to necessary.

2022-11-15 Version: 3.0.46
- MSE.
- Fixed Describe For These API.

2022-11-15 Version: 3.0.45
- Support MSE and AHAS integrated.

2022-11-07 Version: 3.0.44
- Supported MSE Gateway For ResourceGroup.

2022-11-07 Version: 3.0.43
- Supported MSE Gateway For ResourceGroup.

2022-11-04 Version: 3.0.42
- Change some optional segment to necessary.

2022-10-25 Version: 3.0.41
- Automatically generate sdk tasks.

2022-10-14 Version: 3.0.40
- Automatically generate sdk tasks.

2022-10-13 Version: 3.0.39
- Automatically generate sdk tasks.

2022-10-12 Version: 3.0.38
- Add normandy api.

2022-09-28 Version: 3.0.30
- Automatically generate sdk tasks.

2022-09-27 Version: 3.0.29
- Automatically generate sdk tasks.

2022-09-27 Version: 3.0.28
- Automatically generate sdk tasks.

2022-09-22 Version: 3.0.27
- Automatically generate sdk tasks.

2022-09-21 Version: 3.0.26
- Automatically generate sdk tasks.

2022-09-15 Version: 3.0.25
- Automatically generate sdk tasks.

2022-09-15 Version: 3.0.24
- Automatically generate sdk tasks.

2022-06-21 Version: 3.0.23
- Add Seata List Cluster open.
- Add Seata List Group.

2022-06-20 Version: 3.0.22
- Add UpdateGatewaySpec open.
- Add UpdateClusterSpec open.

2022-02-18 Version: 3.0.9
- Add Gateway route api.

2021-10-12 Version: 1.0.1
- Add AddRoutePolicyRequest.

2021-04-15 Version: 1.0.0
- Publish first version.
